@@ -6,6 +6,7 @@ Classes are provided for individual Systems as well as groups of Systems (System
 from __future__ import annotations
 
 import itertools
+import logging
 from typing import TYPE_CHECKING, Union
 from datetime import datetime
 from functools import cached_property
@@ -15,6 +16,7 @@ import pandas as pd
 
 from sailor import _base
 from sailor import sap_iot
+from sailor.utils.utils import WarningAdapter
 from .utils import (AssetcentralEntity, _AssetcentralField, AssetcentralEntitySet,
                     _ac_application_url, _ac_fetch_data)
 from .equipment import find_equipment, EquipmentSet
@@ -57,6 +59,10 @@ _SYSTEM_FIELDS = [
     _AssetcentralField('_completeness', 'completeness'),
 ]
 
+LOG = logging.getLogger(__name__)
+LOG.addHandler(logging.NullHandler())
+LOG = WarningAdapter(LOG)
+
 
 @_base.add_properties
 class System(AssetcentralEntity):
@@ -146,7 +152,8 @@ class System(AssetcentralEntity):
         return selection
 
     def get_indicator_data(self, start: Union[str, pd.Timestamp, datetime.timestamp, datetime.date],
-                           end: Union[str, pd.Timestamp, datetime.timestamp, datetime.date]) -> TimeseriesDataset:
+                           end: Union[str, pd.Timestamp, datetime.timestamp, datetime.date], *,
+                           timeout: Union[str, pd.Timedelta, datetime.timedelta] = None) -> TimeseriesDataset:
         """
         Get timeseries data for all Equipment in the System.
 
@@ -163,10 +170,16 @@ class System(AssetcentralEntity):
             Begin of time series data.
         end
             End of time series data.
+        timeout
+            Maximum amount of time the request may take. Can be specified as an ISO 8601 string
+            (like `PT2M` for 2-minute duration) or as a pandas.Timedelta or datetime.timedelta object.
+            If None, there is no time limit.
         """
         all_indicators = sum((equi.find_equipment_indicators() for equi in self._hierarchy['equipment']),
                              IndicatorSet([]))
-        return sap_iot.get_indicator_data(start, end, all_indicators, self._hierarchy['equipment'])
+
+        LOG.debug('Requesting indicator data of system "%s" for %d indicators.', self.id, len(all_indicators))
+        return sap_iot.get_indicator_data(start, end, all_indicators, self._hierarchy['equipment'], timeout=timeout)
 
 
 class SystemSet(AssetcentralEntitySet):
@@ -180,7 +193,8 @@ class SystemSet(AssetcentralEntitySet):
     }
 
     def get_indicator_data(self, start: Union[str, pd.Timestamp, datetime.timestamp, datetime.date],
-                           end: Union[str, pd.Timestamp, datetime.timestamp, datetime.date]) -> TimeseriesDataset:
+                           end: Union[str, pd.Timestamp, datetime.timestamp, datetime.date], *,
+                           timeout: Union[str, pd.Timedelta, datetime.timedelta] = None) -> TimeseriesDataset:
         """
         Fetch data for a set of systems for all component equipment of each system.
 
@@ -196,11 +210,17 @@ class SystemSet(AssetcentralEntitySet):
             Begin of time series data.
         end
             End of time series data.
+        timeout
+            Maximum amount of time the request may take. Can be specified as an ISO 8601 string
+            (like `PT2M` for 2-minute duration) or as a pandas.Timedelta or datetime.timedelta object.
+            If None, there is no time limit.
         """
         all_equipment = sum((system._hierarchy['equipment'] for system in self), EquipmentSet([]))
         all_indicators = sum((equipment.find_equipment_indicators() for equipment in all_equipment), IndicatorSet([]))
+        LOG.debug("Requesting indicator data of system set for %d equipments and %d indicators.",
+                  len(all_equipment), len(all_indicators))
 
-        return sap_iot.get_indicator_data(start, end, all_indicators, all_equipment)
+        return sap_iot.get_indicator_data(start, end, all_indicators, all_equipment, timeout=timeout)
 
     @staticmethod
     def _fill_nones(sel_nodes, indicator_list, none_positions):
@@ -303,5 +323,6 @@ def find_systems(*, extended_filters=(), **kwargs) -> SystemSet:
 
     endpoint_url = _ac_application_url() + VIEW_SYSTEMS
     object_list = _ac_fetch_data(endpoint_url, unbreakable_filters, breakable_filters)
+    LOG.debug('Found %d systems for the specified filters.', len(object_list))
 
     return SystemSet([System(obj) for obj in object_list])
